# ADR-XXX: [Title]

**Status:** Proposed | Accepted | Deprecated | Superseded by [ADR-YYY]
**Date:** YYYY-MM-DD
**Deciders:** [Names/Teams]

---

## Context

[Why this decision is needed. What problem does it solve? What constraints exist?]

**Example:**
- Current implementation: [brief description]
- Problem: [specific issue]
- Constraints: [technical/business limitations]

---

## Decision

[What we decided to do. Be specific and actionable.]

**Example:**
We will use [technology/approach] because [primary reason].

---

## Consequences

### Positive
- [Benefit 1]
- [Benefit 2]

### Negative
- [Trade-off 1]
- [Trade-off 2]

### Risks
- [Risk 1] → Mitigation: [approach]
- [Risk 2] → Mitigation: [approach]

---

## Alternatives Considered

### Option A: [Name]
- Pros: [list]
- Cons: [list]
- Rejected because: [reason]

### Option B: [Name]
- Pros: [list]
- Cons: [list]
- Rejected because: [reason]

---

## Notes

[Additional context, links, references]
